"""Stub file for reflex_enterprise/components/mantine/dates.py"""

# ------------------- DO NOT EDIT ----------------------
# This file was generated by `reflex/utils/pyi_generator.py`!
# ------------------------------------------------------
from typing import Any, Callable, Literal, Mapping, Optional, Sequence, TypedDict

import reflex as rx
from reflex.components.component import Component
from reflex.components.core.breakpoints import Breakpoints
from reflex.event import EventType, PointerEventInfo
from reflex.vars.base import Var

from reflex_enterprise.components.component import ComponentEnterprise

from .base import (
    MantineDescriptionProps,
    MantineErrorProps,
    MantineLabelProps,
    MantineLeftSection,
    MantineRightSection,
)

MANTINE_DATES_PACKAGE = "@mantine/dates"
MANTINE_DATES_VERSION = "8.3.9"

class MantineDates(ComponentEnterprise):
    def add_imports(self): ...
    @classmethod
    def create(
        cls,
        *children,
        style: Sequence[Mapping[str, Any]]
        | Mapping[str, Any]
        | Var[Mapping[str, Any]]
        | Breakpoints
        | None = None,
        key: Any | None = None,
        id: Any | None = None,
        ref: Var | None = None,
        class_name: Any | None = None,
        custom_attrs: dict[str, Var | Any] | None = None,
        on_blur: Optional[EventType[()]] = None,
        on_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_context_menu: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_double_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_focus: Optional[EventType[()]] = None,
        on_mount: Optional[EventType[()]] = None,
        on_mouse_down: Optional[EventType[()]] = None,
        on_mouse_enter: Optional[EventType[()]] = None,
        on_mouse_leave: Optional[EventType[()]] = None,
        on_mouse_move: Optional[EventType[()]] = None,
        on_mouse_out: Optional[EventType[()]] = None,
        on_mouse_over: Optional[EventType[()]] = None,
        on_mouse_up: Optional[EventType[()]] = None,
        on_scroll: Optional[EventType[()]] = None,
        on_scroll_end: Optional[EventType[()]] = None,
        on_unmount: Optional[EventType[()]] = None,
        **props,
    ) -> "MantineDates":
        """Create the Reflex Enterprise component."""
        ...

class CalendarEvents(ComponentEnterprise):
    @classmethod
    def create(
        cls,
        *children,
        style: Sequence[Mapping[str, Any]]
        | Mapping[str, Any]
        | Var[Mapping[str, Any]]
        | Breakpoints
        | None = None,
        key: Any | None = None,
        id: Any | None = None,
        ref: Var | None = None,
        class_name: Any | None = None,
        custom_attrs: dict[str, Var | Any] | None = None,
        on_blur: Optional[EventType[()]] = None,
        on_change: Optional[EventType[()] | EventType[str]] = None,
        on_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_context_menu: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_date_change: Optional[EventType[()] | EventType[str]] = None,
        on_double_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_focus: Optional[EventType[()]] = None,
        on_level_change: Optional[EventType[()] | EventType[str]] = None,
        on_month_select: Optional[EventType[()] | EventType[str]] = None,
        on_mount: Optional[EventType[()]] = None,
        on_mouse_down: Optional[EventType[()]] = None,
        on_mouse_enter: Optional[EventType[()]] = None,
        on_mouse_leave: Optional[EventType[()]] = None,
        on_mouse_move: Optional[EventType[()]] = None,
        on_mouse_out: Optional[EventType[()]] = None,
        on_mouse_over: Optional[EventType[()]] = None,
        on_mouse_up: Optional[EventType[()]] = None,
        on_next_decade: Optional[EventType[()] | EventType[str]] = None,
        on_next_month: Optional[EventType[()] | EventType[str]] = None,
        on_next_year: Optional[EventType[()] | EventType[str]] = None,
        on_previous_decade: Optional[EventType[()] | EventType[str]] = None,
        on_previous_month: Optional[EventType[()] | EventType[str]] = None,
        on_previous_year: Optional[EventType[()] | EventType[str]] = None,
        on_scroll: Optional[EventType[()]] = None,
        on_scroll_end: Optional[EventType[()]] = None,
        on_unmount: Optional[EventType[()]] = None,
        on_year_control_mouse_enter: Optional[EventType[()] | EventType[str]] = None,
        on_year_select: Optional[EventType[()] | EventType[str]] = None,
        **props,
    ) -> "CalendarEvents":
        """Create the Reflex Enterprise component."""
        ...

class PresetEntry(TypedDict):
    value: str | tuple[str, str]
    label: str

class SharedCalendarProps(ComponentEnterprise):
    @classmethod
    def create(
        cls,
        *children,
        aria_labels: Var[dict[str, str]] | dict[str, str] | None = None,
        columns_to_scroll: Var[int] | int | None = None,
        date: Var[str] | str | None = None,
        decade_label_format: Var[str] | str | None = None,
        default_date: Var[str] | str | None = None,
        default_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        first_day_of_week: Var[int] | int | None = None,
        get_day_aria_label: Callable | Var[Callable] | None = None,
        get_day_props: Callable | Var[Callable] | None = None,
        get_month_control_props: Callable | Var[Callable] | None = None,
        get_year_control_props: Callable | Var[Callable] | None = None,
        hide_outside_dates: Var[bool] | bool | None = None,
        hide_weekdays: Var[bool] | bool | None = None,
        highlight_today: Var[bool] | bool | None = None,
        level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        locale: Var[str] | str | None = None,
        max_date: Var[str] | str | None = None,
        max_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        min_date: Var[str] | str | None = None,
        min_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        month_label_format: Var[str] | str | None = None,
        month_format: Var[str] | str | None = None,
        next_icon: Component | Var[Component] | None = None,
        next_label: Var[str] | str | None = None,
        number_of_columns: Var[int] | int | None = None,
        presets: Var[list[PresetEntry]] | list[PresetEntry] | None = None,
        previous_icon: Component | Var[Component] | None = None,
        previous_label: Var[str] | str | None = None,
        render_day: Callable | Var[Callable] | None = None,
        size: Literal["lg", "md", "sm", "xl", "xs"]
        | Var[Literal["lg", "md", "sm", "xl", "xs"]]
        | None = None,
        weekday_format: Var[str] | str | None = None,
        weekend_days: Var[list[int]] | list[int] | None = None,
        with_cell_spacing: Var[bool] | bool | None = None,
        with_week_numbers: Var[bool] | bool | None = None,
        year_label_format: Var[str] | str | None = None,
        year_list_format: Var[str] | str | None = None,
        style: Sequence[Mapping[str, Any]]
        | Mapping[str, Any]
        | Var[Mapping[str, Any]]
        | Breakpoints
        | None = None,
        key: Any | None = None,
        id: Any | None = None,
        ref: Var | None = None,
        class_name: Any | None = None,
        custom_attrs: dict[str, Var | Any] | None = None,
        on_blur: Optional[EventType[()]] = None,
        on_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_context_menu: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_double_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_focus: Optional[EventType[()]] = None,
        on_mount: Optional[EventType[()]] = None,
        on_mouse_down: Optional[EventType[()]] = None,
        on_mouse_enter: Optional[EventType[()]] = None,
        on_mouse_leave: Optional[EventType[()]] = None,
        on_mouse_move: Optional[EventType[()]] = None,
        on_mouse_out: Optional[EventType[()]] = None,
        on_mouse_over: Optional[EventType[()]] = None,
        on_mouse_up: Optional[EventType[()]] = None,
        on_scroll: Optional[EventType[()]] = None,
        on_scroll_end: Optional[EventType[()]] = None,
        on_unmount: Optional[EventType[()]] = None,
        **props,
    ) -> "SharedCalendarProps":
        """Create the Reflex Enterprise component."""
        ...

class BareCalendar(MantineDates, SharedCalendarProps, CalendarEvents):
    @classmethod
    def create(
        cls,
        *children,
        aria_labels: Var[dict[str, str]] | dict[str, str] | None = None,
        columns_to_scroll: Var[int] | int | None = None,
        date: Var[str] | str | None = None,
        decade_label_format: Var[str] | str | None = None,
        default_date: Var[str] | str | None = None,
        default_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        first_day_of_week: Var[int] | int | None = None,
        get_day_aria_label: Callable | Var[Callable] | None = None,
        get_day_props: Callable | Var[Callable] | None = None,
        get_month_control_props: Callable | Var[Callable] | None = None,
        get_year_control_props: Callable | Var[Callable] | None = None,
        hide_outside_dates: Var[bool] | bool | None = None,
        hide_weekdays: Var[bool] | bool | None = None,
        highlight_today: Var[bool] | bool | None = None,
        level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        locale: Var[str] | str | None = None,
        max_date: Var[str] | str | None = None,
        max_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        min_date: Var[str] | str | None = None,
        min_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        month_label_format: Var[str] | str | None = None,
        month_format: Var[str] | str | None = None,
        next_icon: Component | Var[Component] | None = None,
        next_label: Var[str] | str | None = None,
        number_of_columns: Var[int] | int | None = None,
        presets: Var[list[PresetEntry]] | list[PresetEntry] | None = None,
        previous_icon: Component | Var[Component] | None = None,
        previous_label: Var[str] | str | None = None,
        render_day: Callable | Var[Callable] | None = None,
        size: Literal["lg", "md", "sm", "xl", "xs"]
        | Var[Literal["lg", "md", "sm", "xl", "xs"]]
        | None = None,
        weekday_format: Var[str] | str | None = None,
        weekend_days: Var[list[int]] | list[int] | None = None,
        with_cell_spacing: Var[bool] | bool | None = None,
        with_week_numbers: Var[bool] | bool | None = None,
        year_label_format: Var[str] | str | None = None,
        year_list_format: Var[str] | str | None = None,
        style: Sequence[Mapping[str, Any]]
        | Mapping[str, Any]
        | Var[Mapping[str, Any]]
        | Breakpoints
        | None = None,
        key: Any | None = None,
        id: Any | None = None,
        ref: Var | None = None,
        class_name: Any | None = None,
        custom_attrs: dict[str, Var | Any] | None = None,
        on_blur: Optional[EventType[()]] = None,
        on_change: Optional[EventType[()] | EventType[str]] = None,
        on_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_context_menu: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_date_change: Optional[EventType[()] | EventType[str]] = None,
        on_double_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_focus: Optional[EventType[()]] = None,
        on_level_change: Optional[EventType[()] | EventType[str]] = None,
        on_month_select: Optional[EventType[()] | EventType[str]] = None,
        on_mount: Optional[EventType[()]] = None,
        on_mouse_down: Optional[EventType[()]] = None,
        on_mouse_enter: Optional[EventType[()]] = None,
        on_mouse_leave: Optional[EventType[()]] = None,
        on_mouse_move: Optional[EventType[()]] = None,
        on_mouse_out: Optional[EventType[()]] = None,
        on_mouse_over: Optional[EventType[()]] = None,
        on_mouse_up: Optional[EventType[()]] = None,
        on_next_decade: Optional[EventType[()] | EventType[str]] = None,
        on_next_month: Optional[EventType[()] | EventType[str]] = None,
        on_next_year: Optional[EventType[()] | EventType[str]] = None,
        on_previous_decade: Optional[EventType[()] | EventType[str]] = None,
        on_previous_month: Optional[EventType[()] | EventType[str]] = None,
        on_previous_year: Optional[EventType[()] | EventType[str]] = None,
        on_scroll: Optional[EventType[()]] = None,
        on_scroll_end: Optional[EventType[()]] = None,
        on_unmount: Optional[EventType[()]] = None,
        on_year_control_mouse_enter: Optional[EventType[()] | EventType[str]] = None,
        on_year_select: Optional[EventType[()] | EventType[str]] = None,
        **props,
    ) -> "BareCalendar":
        """Create the Reflex Enterprise component."""
        ...

class Calendar(BareCalendar):
    @classmethod
    def create(
        cls,
        *children,
        has_next_level: Var[bool] | bool | None = None,
        static: Var[bool] | bool | None = None,
        aria_labels: Var[dict[str, str]] | dict[str, str] | None = None,
        columns_to_scroll: Var[int] | int | None = None,
        date: Var[str] | str | None = None,
        decade_label_format: Var[str] | str | None = None,
        default_date: Var[str] | str | None = None,
        default_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        first_day_of_week: Var[int] | int | None = None,
        get_day_aria_label: Callable | Var[Callable] | None = None,
        get_day_props: Callable | Var[Callable] | None = None,
        get_month_control_props: Callable | Var[Callable] | None = None,
        get_year_control_props: Callable | Var[Callable] | None = None,
        hide_outside_dates: Var[bool] | bool | None = None,
        hide_weekdays: Var[bool] | bool | None = None,
        highlight_today: Var[bool] | bool | None = None,
        level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        locale: Var[str] | str | None = None,
        max_date: Var[str] | str | None = None,
        max_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        min_date: Var[str] | str | None = None,
        min_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        month_label_format: Var[str] | str | None = None,
        month_format: Var[str] | str | None = None,
        next_icon: Component | Var[Component] | None = None,
        next_label: Var[str] | str | None = None,
        number_of_columns: Var[int] | int | None = None,
        presets: Var[list[PresetEntry]] | list[PresetEntry] | None = None,
        previous_icon: Component | Var[Component] | None = None,
        previous_label: Var[str] | str | None = None,
        render_day: Callable | Var[Callable] | None = None,
        size: Literal["lg", "md", "sm", "xl", "xs"]
        | Var[Literal["lg", "md", "sm", "xl", "xs"]]
        | None = None,
        weekday_format: Var[str] | str | None = None,
        weekend_days: Var[list[int]] | list[int] | None = None,
        with_cell_spacing: Var[bool] | bool | None = None,
        with_week_numbers: Var[bool] | bool | None = None,
        year_label_format: Var[str] | str | None = None,
        year_list_format: Var[str] | str | None = None,
        style: Sequence[Mapping[str, Any]]
        | Mapping[str, Any]
        | Var[Mapping[str, Any]]
        | Breakpoints
        | None = None,
        key: Any | None = None,
        id: Any | None = None,
        ref: Var | None = None,
        class_name: Any | None = None,
        custom_attrs: dict[str, Var | Any] | None = None,
        on_blur: Optional[EventType[()]] = None,
        on_change: Optional[EventType[()] | EventType[str]] = None,
        on_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_context_menu: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_date_change: Optional[EventType[()] | EventType[str]] = None,
        on_double_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_focus: Optional[EventType[()]] = None,
        on_level_change: Optional[EventType[()] | EventType[str]] = None,
        on_month_control_mouse_enter: Optional[EventType[()] | EventType[str]] = None,
        on_month_select: Optional[EventType[()] | EventType[str]] = None,
        on_mount: Optional[EventType[()]] = None,
        on_mouse_down: Optional[EventType[()]] = None,
        on_mouse_enter: Optional[EventType[()]] = None,
        on_mouse_leave: Optional[EventType[()]] = None,
        on_mouse_move: Optional[EventType[()]] = None,
        on_mouse_out: Optional[EventType[()]] = None,
        on_mouse_over: Optional[EventType[()]] = None,
        on_mouse_up: Optional[EventType[()]] = None,
        on_next_decade: Optional[EventType[()] | EventType[str]] = None,
        on_next_month: Optional[EventType[()] | EventType[str]] = None,
        on_next_year: Optional[EventType[()] | EventType[str]] = None,
        on_previous_decade: Optional[EventType[()] | EventType[str]] = None,
        on_previous_month: Optional[EventType[()] | EventType[str]] = None,
        on_previous_year: Optional[EventType[()] | EventType[str]] = None,
        on_scroll: Optional[EventType[()]] = None,
        on_scroll_end: Optional[EventType[()]] = None,
        on_unmount: Optional[EventType[()]] = None,
        on_year_control_mouse_enter: Optional[EventType[()] | EventType[str]] = None,
        on_year_select: Optional[EventType[()] | EventType[str]] = None,
        **props,
    ) -> "Calendar":
        """Create the Reflex Enterprise component."""
        ...

class BareCalendarPicker(
    BareCalendar,
    MantineLabelProps,
    MantineErrorProps,
    MantineDescriptionProps,
    MantineLeftSection,
    MantineRightSection,
):
    @classmethod
    def create(
        cls,
        *children,
        placeholder: Var[str] | str | None = None,
        aria_labels: Var[dict[str, str]] | dict[str, str] | None = None,
        columns_to_scroll: Var[int] | int | None = None,
        date: Var[str] | str | None = None,
        decade_label_format: Var[str] | str | None = None,
        default_date: Var[str] | str | None = None,
        default_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        first_day_of_week: Var[int] | int | None = None,
        get_day_aria_label: Callable | Var[Callable] | None = None,
        get_day_props: Callable | Var[Callable] | None = None,
        get_month_control_props: Callable | Var[Callable] | None = None,
        get_year_control_props: Callable | Var[Callable] | None = None,
        hide_outside_dates: Var[bool] | bool | None = None,
        hide_weekdays: Var[bool] | bool | None = None,
        highlight_today: Var[bool] | bool | None = None,
        level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        locale: Var[str] | str | None = None,
        max_date: Var[str] | str | None = None,
        max_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        min_date: Var[str] | str | None = None,
        min_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        month_label_format: Var[str] | str | None = None,
        month_format: Var[str] | str | None = None,
        next_icon: Component | Var[Component] | None = None,
        next_label: Var[str] | str | None = None,
        number_of_columns: Var[int] | int | None = None,
        presets: Var[list[PresetEntry]] | list[PresetEntry] | None = None,
        previous_icon: Component | Var[Component] | None = None,
        previous_label: Var[str] | str | None = None,
        render_day: Callable | Var[Callable] | None = None,
        size: Literal["lg", "md", "sm", "xl", "xs"]
        | Var[Literal["lg", "md", "sm", "xl", "xs"]]
        | None = None,
        weekday_format: Var[str] | str | None = None,
        weekend_days: Var[list[int]] | list[int] | None = None,
        with_cell_spacing: Var[bool] | bool | None = None,
        with_week_numbers: Var[bool] | bool | None = None,
        year_label_format: Var[str] | str | None = None,
        year_list_format: Var[str] | str | None = None,
        label: Component | Var[Component | str] | str | None = None,
        label_props: Var[dict] | dict | None = None,
        error: Component | Var[Component | bool | str] | bool | str | None = None,
        error_props: Var[dict] | dict | None = None,
        description: Component | Var[Component | str] | str | None = None,
        description_props: Var[dict] | dict | None = None,
        style: Sequence[Mapping[str, Any]]
        | Mapping[str, Any]
        | Var[Mapping[str, Any]]
        | Breakpoints
        | None = None,
        key: Any | None = None,
        id: Any | None = None,
        ref: Var | None = None,
        class_name: Any | None = None,
        custom_attrs: dict[str, Var | Any] | None = None,
        left_section: Component | Var[Component | str] | str | None = None,
        left_section_props: Var[dict] | dict | None = None,
        left_section_width: Var[float | str] | float | str | None = None,
        left_section_pointer_events: Var[str] | str | None = None,
        right_section: Component | Var[Component | str] | str | None = None,
        right_section_props: Var[dict] | dict | None = None,
        right_section_width: Var[float | str] | float | str | None = None,
        right_section_pointer_events: Var[str] | str | None = None,
        on_blur: Optional[EventType[()]] = None,
        on_change: Optional[EventType[()] | EventType[str]] = None,
        on_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_context_menu: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_date_change: Optional[EventType[()] | EventType[str]] = None,
        on_double_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_focus: Optional[EventType[()]] = None,
        on_level_change: Optional[EventType[()] | EventType[str]] = None,
        on_month_select: Optional[EventType[()] | EventType[str]] = None,
        on_mount: Optional[EventType[()]] = None,
        on_mouse_down: Optional[EventType[()]] = None,
        on_mouse_enter: Optional[EventType[()]] = None,
        on_mouse_leave: Optional[EventType[()]] = None,
        on_mouse_move: Optional[EventType[()]] = None,
        on_mouse_out: Optional[EventType[()]] = None,
        on_mouse_over: Optional[EventType[()]] = None,
        on_mouse_up: Optional[EventType[()]] = None,
        on_next_decade: Optional[EventType[()] | EventType[str]] = None,
        on_next_month: Optional[EventType[()] | EventType[str]] = None,
        on_next_year: Optional[EventType[()] | EventType[str]] = None,
        on_previous_decade: Optional[EventType[()] | EventType[str]] = None,
        on_previous_month: Optional[EventType[()] | EventType[str]] = None,
        on_previous_year: Optional[EventType[()] | EventType[str]] = None,
        on_scroll: Optional[EventType[()]] = None,
        on_scroll_end: Optional[EventType[()]] = None,
        on_unmount: Optional[EventType[()]] = None,
        on_year_control_mouse_enter: Optional[EventType[()] | EventType[str]] = None,
        on_year_select: Optional[EventType[()] | EventType[str]] = None,
        **props,
    ) -> "BareCalendarPicker":
        """Create the Reflex Enterprise component."""
        ...

class DateTimePicker(BareCalendarPicker):
    @classmethod
    def create(
        cls,
        *children,
        date: Var[str] | str | None = None,
        allow_deselect: Var[bool] | bool | None = None,
        allow_single_day_range: Var[bool] | bool | None = None,
        default_date: Var[str] | str | None = None,
        decade_label_format: Var[str] | str | None = None,
        first_day_of_week: Var[int] | int | None = None,
        get_day_props: Callable | Var[Callable] | None = None,
        placeholder: Var[str] | str | None = None,
        aria_labels: Var[dict[str, str]] | dict[str, str] | None = None,
        columns_to_scroll: Var[int] | int | None = None,
        default_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        get_day_aria_label: Callable | Var[Callable] | None = None,
        get_month_control_props: Callable | Var[Callable] | None = None,
        get_year_control_props: Callable | Var[Callable] | None = None,
        hide_outside_dates: Var[bool] | bool | None = None,
        hide_weekdays: Var[bool] | bool | None = None,
        highlight_today: Var[bool] | bool | None = None,
        level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        locale: Var[str] | str | None = None,
        max_date: Var[str] | str | None = None,
        max_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        min_date: Var[str] | str | None = None,
        min_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        month_label_format: Var[str] | str | None = None,
        month_format: Var[str] | str | None = None,
        next_icon: Component | Var[Component] | None = None,
        next_label: Var[str] | str | None = None,
        number_of_columns: Var[int] | int | None = None,
        presets: Var[list[PresetEntry]] | list[PresetEntry] | None = None,
        previous_icon: Component | Var[Component] | None = None,
        previous_label: Var[str] | str | None = None,
        render_day: Callable | Var[Callable] | None = None,
        size: Literal["lg", "md", "sm", "xl", "xs"]
        | Var[Literal["lg", "md", "sm", "xl", "xs"]]
        | None = None,
        weekday_format: Var[str] | str | None = None,
        weekend_days: Var[list[int]] | list[int] | None = None,
        with_cell_spacing: Var[bool] | bool | None = None,
        with_week_numbers: Var[bool] | bool | None = None,
        year_label_format: Var[str] | str | None = None,
        year_list_format: Var[str] | str | None = None,
        label: Component | Var[Component | str] | str | None = None,
        label_props: Var[dict] | dict | None = None,
        error: Component | Var[Component | bool | str] | bool | str | None = None,
        error_props: Var[dict] | dict | None = None,
        description: Component | Var[Component | str] | str | None = None,
        description_props: Var[dict] | dict | None = None,
        style: Sequence[Mapping[str, Any]]
        | Mapping[str, Any]
        | Var[Mapping[str, Any]]
        | Breakpoints
        | None = None,
        key: Any | None = None,
        id: Any | None = None,
        ref: Var | None = None,
        class_name: Any | None = None,
        custom_attrs: dict[str, Var | Any] | None = None,
        left_section: Component | Var[Component | str] | str | None = None,
        left_section_props: Var[dict] | dict | None = None,
        left_section_width: Var[float | str] | float | str | None = None,
        left_section_pointer_events: Var[str] | str | None = None,
        right_section: Component | Var[Component | str] | str | None = None,
        right_section_props: Var[dict] | dict | None = None,
        right_section_width: Var[float | str] | float | str | None = None,
        right_section_pointer_events: Var[str] | str | None = None,
        on_blur: Optional[EventType[()]] = None,
        on_change: Optional[EventType[()] | EventType[str]] = None,
        on_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_context_menu: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_date_change: Optional[EventType[()] | EventType[str]] = None,
        on_double_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_focus: Optional[EventType[()]] = None,
        on_level_change: Optional[EventType[()] | EventType[str]] = None,
        on_month_select: Optional[EventType[()] | EventType[str]] = None,
        on_mount: Optional[EventType[()]] = None,
        on_mouse_down: Optional[EventType[()]] = None,
        on_mouse_enter: Optional[EventType[()]] = None,
        on_mouse_leave: Optional[EventType[()]] = None,
        on_mouse_move: Optional[EventType[()]] = None,
        on_mouse_out: Optional[EventType[()]] = None,
        on_mouse_over: Optional[EventType[()]] = None,
        on_mouse_up: Optional[EventType[()]] = None,
        on_next_decade: Optional[EventType[()] | EventType[str]] = None,
        on_next_month: Optional[EventType[()] | EventType[str]] = None,
        on_next_year: Optional[EventType[()] | EventType[str]] = None,
        on_previous_decade: Optional[EventType[()] | EventType[str]] = None,
        on_previous_month: Optional[EventType[()] | EventType[str]] = None,
        on_previous_year: Optional[EventType[()] | EventType[str]] = None,
        on_scroll: Optional[EventType[()]] = None,
        on_scroll_end: Optional[EventType[()]] = None,
        on_unmount: Optional[EventType[()]] = None,
        on_year_control_mouse_enter: Optional[EventType[()] | EventType[str]] = None,
        on_year_select: Optional[EventType[()] | EventType[str]] = None,
        **props,
    ) -> "DateTimePicker":
        """Create the Reflex Enterprise component."""
        ...

class DatePicker(BareCalendarPicker):
    @classmethod
    def create(
        cls,
        *children,
        date: Var[str] | str | None = None,
        type: Literal["default", "multiple", "range"]
        | Var[Literal["default", "multiple", "range"]]
        | None = None,
        allow_single_day_range: Var[bool] | bool | None = None,
        placeholder: Var[str] | str | None = None,
        aria_labels: Var[dict[str, str]] | dict[str, str] | None = None,
        columns_to_scroll: Var[int] | int | None = None,
        decade_label_format: Var[str] | str | None = None,
        default_date: Var[str] | str | None = None,
        default_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        first_day_of_week: Var[int] | int | None = None,
        get_day_aria_label: Callable | Var[Callable] | None = None,
        get_day_props: Callable | Var[Callable] | None = None,
        get_month_control_props: Callable | Var[Callable] | None = None,
        get_year_control_props: Callable | Var[Callable] | None = None,
        hide_outside_dates: Var[bool] | bool | None = None,
        hide_weekdays: Var[bool] | bool | None = None,
        highlight_today: Var[bool] | bool | None = None,
        level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        locale: Var[str] | str | None = None,
        max_date: Var[str] | str | None = None,
        max_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        min_date: Var[str] | str | None = None,
        min_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        month_label_format: Var[str] | str | None = None,
        month_format: Var[str] | str | None = None,
        next_icon: Component | Var[Component] | None = None,
        next_label: Var[str] | str | None = None,
        number_of_columns: Var[int] | int | None = None,
        presets: Var[list[PresetEntry]] | list[PresetEntry] | None = None,
        previous_icon: Component | Var[Component] | None = None,
        previous_label: Var[str] | str | None = None,
        render_day: Callable | Var[Callable] | None = None,
        size: Literal["lg", "md", "sm", "xl", "xs"]
        | Var[Literal["lg", "md", "sm", "xl", "xs"]]
        | None = None,
        weekday_format: Var[str] | str | None = None,
        weekend_days: Var[list[int]] | list[int] | None = None,
        with_cell_spacing: Var[bool] | bool | None = None,
        with_week_numbers: Var[bool] | bool | None = None,
        year_label_format: Var[str] | str | None = None,
        year_list_format: Var[str] | str | None = None,
        label: Component | Var[Component | str] | str | None = None,
        label_props: Var[dict] | dict | None = None,
        error: Component | Var[Component | bool | str] | bool | str | None = None,
        error_props: Var[dict] | dict | None = None,
        description: Component | Var[Component | str] | str | None = None,
        description_props: Var[dict] | dict | None = None,
        style: Sequence[Mapping[str, Any]]
        | Mapping[str, Any]
        | Var[Mapping[str, Any]]
        | Breakpoints
        | None = None,
        key: Any | None = None,
        id: Any | None = None,
        ref: Var | None = None,
        class_name: Any | None = None,
        custom_attrs: dict[str, Var | Any] | None = None,
        left_section: Component | Var[Component | str] | str | None = None,
        left_section_props: Var[dict] | dict | None = None,
        left_section_width: Var[float | str] | float | str | None = None,
        left_section_pointer_events: Var[str] | str | None = None,
        right_section: Component | Var[Component | str] | str | None = None,
        right_section_props: Var[dict] | dict | None = None,
        right_section_width: Var[float | str] | float | str | None = None,
        right_section_pointer_events: Var[str] | str | None = None,
        on_blur: Optional[EventType[()]] = None,
        on_change: Optional[EventType[()] | EventType[str]] = None,
        on_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_context_menu: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_date_change: Optional[EventType[()] | EventType[str]] = None,
        on_double_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_focus: Optional[EventType[()]] = None,
        on_level_change: Optional[EventType[()] | EventType[str]] = None,
        on_month_select: Optional[EventType[()] | EventType[str]] = None,
        on_mount: Optional[EventType[()]] = None,
        on_mouse_down: Optional[EventType[()]] = None,
        on_mouse_enter: Optional[EventType[()]] = None,
        on_mouse_leave: Optional[EventType[()]] = None,
        on_mouse_move: Optional[EventType[()]] = None,
        on_mouse_out: Optional[EventType[()]] = None,
        on_mouse_over: Optional[EventType[()]] = None,
        on_mouse_up: Optional[EventType[()]] = None,
        on_next_decade: Optional[EventType[()] | EventType[str]] = None,
        on_next_month: Optional[EventType[()] | EventType[str]] = None,
        on_next_year: Optional[EventType[()] | EventType[str]] = None,
        on_previous_decade: Optional[EventType[()] | EventType[str]] = None,
        on_previous_month: Optional[EventType[()] | EventType[str]] = None,
        on_previous_year: Optional[EventType[()] | EventType[str]] = None,
        on_scroll: Optional[EventType[()]] = None,
        on_scroll_end: Optional[EventType[()]] = None,
        on_unmount: Optional[EventType[()]] = None,
        on_year_control_mouse_enter: Optional[EventType[()] | EventType[str]] = None,
        on_year_select: Optional[EventType[()] | EventType[str]] = None,
        **props,
    ) -> "DatePicker":
        """Create the Reflex Enterprise component."""
        ...

class DatePickerInput(BareCalendarPicker):
    @classmethod
    def create(
        cls,
        *children,
        date: Var[str] | str | None = None,
        type: Literal["default", "multiple", "range"]
        | Var[Literal["default", "multiple", "range"]]
        | None = None,
        close_on_change: Var[bool] | bool | None = None,
        allow_single_day_range: Var[bool] | bool | None = None,
        placeholder: Var[str] | str | None = None,
        aria_labels: Var[dict[str, str]] | dict[str, str] | None = None,
        columns_to_scroll: Var[int] | int | None = None,
        decade_label_format: Var[str] | str | None = None,
        default_date: Var[str] | str | None = None,
        default_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        first_day_of_week: Var[int] | int | None = None,
        get_day_aria_label: Callable | Var[Callable] | None = None,
        get_day_props: Callable | Var[Callable] | None = None,
        get_month_control_props: Callable | Var[Callable] | None = None,
        get_year_control_props: Callable | Var[Callable] | None = None,
        hide_outside_dates: Var[bool] | bool | None = None,
        hide_weekdays: Var[bool] | bool | None = None,
        highlight_today: Var[bool] | bool | None = None,
        level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        locale: Var[str] | str | None = None,
        max_date: Var[str] | str | None = None,
        max_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        min_date: Var[str] | str | None = None,
        min_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        month_label_format: Var[str] | str | None = None,
        month_format: Var[str] | str | None = None,
        next_icon: Component | Var[Component] | None = None,
        next_label: Var[str] | str | None = None,
        number_of_columns: Var[int] | int | None = None,
        presets: Var[list[PresetEntry]] | list[PresetEntry] | None = None,
        previous_icon: Component | Var[Component] | None = None,
        previous_label: Var[str] | str | None = None,
        render_day: Callable | Var[Callable] | None = None,
        size: Literal["lg", "md", "sm", "xl", "xs"]
        | Var[Literal["lg", "md", "sm", "xl", "xs"]]
        | None = None,
        weekday_format: Var[str] | str | None = None,
        weekend_days: Var[list[int]] | list[int] | None = None,
        with_cell_spacing: Var[bool] | bool | None = None,
        with_week_numbers: Var[bool] | bool | None = None,
        year_label_format: Var[str] | str | None = None,
        year_list_format: Var[str] | str | None = None,
        label: Component | Var[Component | str] | str | None = None,
        label_props: Var[dict] | dict | None = None,
        error: Component | Var[Component | bool | str] | bool | str | None = None,
        error_props: Var[dict] | dict | None = None,
        description: Component | Var[Component | str] | str | None = None,
        description_props: Var[dict] | dict | None = None,
        style: Sequence[Mapping[str, Any]]
        | Mapping[str, Any]
        | Var[Mapping[str, Any]]
        | Breakpoints
        | None = None,
        key: Any | None = None,
        id: Any | None = None,
        ref: Var | None = None,
        class_name: Any | None = None,
        custom_attrs: dict[str, Var | Any] | None = None,
        left_section: Component | Var[Component | str] | str | None = None,
        left_section_props: Var[dict] | dict | None = None,
        left_section_width: Var[float | str] | float | str | None = None,
        left_section_pointer_events: Var[str] | str | None = None,
        right_section: Component | Var[Component | str] | str | None = None,
        right_section_props: Var[dict] | dict | None = None,
        right_section_width: Var[float | str] | float | str | None = None,
        right_section_pointer_events: Var[str] | str | None = None,
        on_blur: Optional[EventType[()]] = None,
        on_change: Optional[EventType[()] | EventType[str]] = None,
        on_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_context_menu: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_date_change: Optional[EventType[()] | EventType[str]] = None,
        on_double_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_focus: Optional[EventType[()]] = None,
        on_level_change: Optional[EventType[()] | EventType[str]] = None,
        on_month_select: Optional[EventType[()] | EventType[str]] = None,
        on_mount: Optional[EventType[()]] = None,
        on_mouse_down: Optional[EventType[()]] = None,
        on_mouse_enter: Optional[EventType[()]] = None,
        on_mouse_leave: Optional[EventType[()]] = None,
        on_mouse_move: Optional[EventType[()]] = None,
        on_mouse_out: Optional[EventType[()]] = None,
        on_mouse_over: Optional[EventType[()]] = None,
        on_mouse_up: Optional[EventType[()]] = None,
        on_next_decade: Optional[EventType[()] | EventType[str]] = None,
        on_next_month: Optional[EventType[()] | EventType[str]] = None,
        on_next_year: Optional[EventType[()] | EventType[str]] = None,
        on_previous_decade: Optional[EventType[()] | EventType[str]] = None,
        on_previous_month: Optional[EventType[()] | EventType[str]] = None,
        on_previous_year: Optional[EventType[()] | EventType[str]] = None,
        on_scroll: Optional[EventType[()]] = None,
        on_scroll_end: Optional[EventType[()]] = None,
        on_unmount: Optional[EventType[()]] = None,
        on_year_control_mouse_enter: Optional[EventType[()] | EventType[str]] = None,
        on_year_select: Optional[EventType[()] | EventType[str]] = None,
        **props,
    ) -> "DatePickerInput":
        """Create the Reflex Enterprise component."""
        ...

class DateInput(BareCalendarPicker):
    @classmethod
    def create(
        cls,
        *children,
        date: Var[str] | str | None = None,
        close_on_change: Var[bool] | bool | None = None,
        allow_single_day_range: Var[bool] | bool | None = None,
        placeholder: Var[str] | str | None = None,
        aria_labels: Var[dict[str, str]] | dict[str, str] | None = None,
        columns_to_scroll: Var[int] | int | None = None,
        decade_label_format: Var[str] | str | None = None,
        default_date: Var[str] | str | None = None,
        default_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        first_day_of_week: Var[int] | int | None = None,
        get_day_aria_label: Callable | Var[Callable] | None = None,
        get_day_props: Callable | Var[Callable] | None = None,
        get_month_control_props: Callable | Var[Callable] | None = None,
        get_year_control_props: Callable | Var[Callable] | None = None,
        hide_outside_dates: Var[bool] | bool | None = None,
        hide_weekdays: Var[bool] | bool | None = None,
        highlight_today: Var[bool] | bool | None = None,
        level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        locale: Var[str] | str | None = None,
        max_date: Var[str] | str | None = None,
        max_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        min_date: Var[str] | str | None = None,
        min_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        month_label_format: Var[str] | str | None = None,
        month_format: Var[str] | str | None = None,
        next_icon: Component | Var[Component] | None = None,
        next_label: Var[str] | str | None = None,
        number_of_columns: Var[int] | int | None = None,
        presets: Var[list[PresetEntry]] | list[PresetEntry] | None = None,
        previous_icon: Component | Var[Component] | None = None,
        previous_label: Var[str] | str | None = None,
        render_day: Callable | Var[Callable] | None = None,
        size: Literal["lg", "md", "sm", "xl", "xs"]
        | Var[Literal["lg", "md", "sm", "xl", "xs"]]
        | None = None,
        weekday_format: Var[str] | str | None = None,
        weekend_days: Var[list[int]] | list[int] | None = None,
        with_cell_spacing: Var[bool] | bool | None = None,
        with_week_numbers: Var[bool] | bool | None = None,
        year_label_format: Var[str] | str | None = None,
        year_list_format: Var[str] | str | None = None,
        label: Component | Var[Component | str] | str | None = None,
        label_props: Var[dict] | dict | None = None,
        error: Component | Var[Component | bool | str] | bool | str | None = None,
        error_props: Var[dict] | dict | None = None,
        description: Component | Var[Component | str] | str | None = None,
        description_props: Var[dict] | dict | None = None,
        style: Sequence[Mapping[str, Any]]
        | Mapping[str, Any]
        | Var[Mapping[str, Any]]
        | Breakpoints
        | None = None,
        key: Any | None = None,
        id: Any | None = None,
        ref: Var | None = None,
        class_name: Any | None = None,
        custom_attrs: dict[str, Var | Any] | None = None,
        left_section: Component | Var[Component | str] | str | None = None,
        left_section_props: Var[dict] | dict | None = None,
        left_section_width: Var[float | str] | float | str | None = None,
        left_section_pointer_events: Var[str] | str | None = None,
        right_section: Component | Var[Component | str] | str | None = None,
        right_section_props: Var[dict] | dict | None = None,
        right_section_width: Var[float | str] | float | str | None = None,
        right_section_pointer_events: Var[str] | str | None = None,
        on_blur: Optional[EventType[()]] = None,
        on_change: Optional[EventType[()] | EventType[str]] = None,
        on_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_context_menu: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_date_change: Optional[EventType[()] | EventType[str]] = None,
        on_double_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_focus: Optional[EventType[()]] = None,
        on_level_change: Optional[EventType[()] | EventType[str]] = None,
        on_month_select: Optional[EventType[()] | EventType[str]] = None,
        on_mount: Optional[EventType[()]] = None,
        on_mouse_down: Optional[EventType[()]] = None,
        on_mouse_enter: Optional[EventType[()]] = None,
        on_mouse_leave: Optional[EventType[()]] = None,
        on_mouse_move: Optional[EventType[()]] = None,
        on_mouse_out: Optional[EventType[()]] = None,
        on_mouse_over: Optional[EventType[()]] = None,
        on_mouse_up: Optional[EventType[()]] = None,
        on_next_decade: Optional[EventType[()] | EventType[str]] = None,
        on_next_month: Optional[EventType[()] | EventType[str]] = None,
        on_next_year: Optional[EventType[()] | EventType[str]] = None,
        on_previous_decade: Optional[EventType[()] | EventType[str]] = None,
        on_previous_month: Optional[EventType[()] | EventType[str]] = None,
        on_previous_year: Optional[EventType[()] | EventType[str]] = None,
        on_scroll: Optional[EventType[()]] = None,
        on_scroll_end: Optional[EventType[()]] = None,
        on_unmount: Optional[EventType[()]] = None,
        on_year_control_mouse_enter: Optional[EventType[()] | EventType[str]] = None,
        on_year_select: Optional[EventType[()] | EventType[str]] = None,
        **props,
    ) -> "DateInput":
        """Create the Reflex Enterprise component."""
        ...

class MonthPicker(BareCalendarPicker):
    @classmethod
    def create(
        cls,
        *children,
        date: Var[str] | str | None = None,
        default_date: Var[str] | str | None = None,
        placeholder: Var[str] | str | None = None,
        aria_labels: Var[dict[str, str]] | dict[str, str] | None = None,
        columns_to_scroll: Var[int] | int | None = None,
        decade_label_format: Var[str] | str | None = None,
        default_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        first_day_of_week: Var[int] | int | None = None,
        get_day_aria_label: Callable | Var[Callable] | None = None,
        get_day_props: Callable | Var[Callable] | None = None,
        get_month_control_props: Callable | Var[Callable] | None = None,
        get_year_control_props: Callable | Var[Callable] | None = None,
        hide_outside_dates: Var[bool] | bool | None = None,
        hide_weekdays: Var[bool] | bool | None = None,
        highlight_today: Var[bool] | bool | None = None,
        level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        locale: Var[str] | str | None = None,
        max_date: Var[str] | str | None = None,
        max_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        min_date: Var[str] | str | None = None,
        min_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        month_label_format: Var[str] | str | None = None,
        month_format: Var[str] | str | None = None,
        next_icon: Component | Var[Component] | None = None,
        next_label: Var[str] | str | None = None,
        number_of_columns: Var[int] | int | None = None,
        presets: Var[list[PresetEntry]] | list[PresetEntry] | None = None,
        previous_icon: Component | Var[Component] | None = None,
        previous_label: Var[str] | str | None = None,
        render_day: Callable | Var[Callable] | None = None,
        size: Literal["lg", "md", "sm", "xl", "xs"]
        | Var[Literal["lg", "md", "sm", "xl", "xs"]]
        | None = None,
        weekday_format: Var[str] | str | None = None,
        weekend_days: Var[list[int]] | list[int] | None = None,
        with_cell_spacing: Var[bool] | bool | None = None,
        with_week_numbers: Var[bool] | bool | None = None,
        year_label_format: Var[str] | str | None = None,
        year_list_format: Var[str] | str | None = None,
        label: Component | Var[Component | str] | str | None = None,
        label_props: Var[dict] | dict | None = None,
        error: Component | Var[Component | bool | str] | bool | str | None = None,
        error_props: Var[dict] | dict | None = None,
        description: Component | Var[Component | str] | str | None = None,
        description_props: Var[dict] | dict | None = None,
        style: Sequence[Mapping[str, Any]]
        | Mapping[str, Any]
        | Var[Mapping[str, Any]]
        | Breakpoints
        | None = None,
        key: Any | None = None,
        id: Any | None = None,
        ref: Var | None = None,
        class_name: Any | None = None,
        custom_attrs: dict[str, Var | Any] | None = None,
        left_section: Component | Var[Component | str] | str | None = None,
        left_section_props: Var[dict] | dict | None = None,
        left_section_width: Var[float | str] | float | str | None = None,
        left_section_pointer_events: Var[str] | str | None = None,
        right_section: Component | Var[Component | str] | str | None = None,
        right_section_props: Var[dict] | dict | None = None,
        right_section_width: Var[float | str] | float | str | None = None,
        right_section_pointer_events: Var[str] | str | None = None,
        on_blur: Optional[EventType[()]] = None,
        on_change: Optional[EventType[()] | EventType[str]] = None,
        on_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_context_menu: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_date_change: Optional[EventType[()] | EventType[str]] = None,
        on_double_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_focus: Optional[EventType[()]] = None,
        on_level_change: Optional[EventType[()] | EventType[str]] = None,
        on_month_select: Optional[EventType[()] | EventType[str]] = None,
        on_mount: Optional[EventType[()]] = None,
        on_mouse_down: Optional[EventType[()]] = None,
        on_mouse_enter: Optional[EventType[()]] = None,
        on_mouse_leave: Optional[EventType[()]] = None,
        on_mouse_move: Optional[EventType[()]] = None,
        on_mouse_out: Optional[EventType[()]] = None,
        on_mouse_over: Optional[EventType[()]] = None,
        on_mouse_up: Optional[EventType[()]] = None,
        on_next_decade: Optional[EventType[()] | EventType[str]] = None,
        on_next_month: Optional[EventType[()] | EventType[str]] = None,
        on_next_year: Optional[EventType[()] | EventType[str]] = None,
        on_previous_decade: Optional[EventType[()] | EventType[str]] = None,
        on_previous_month: Optional[EventType[()] | EventType[str]] = None,
        on_previous_year: Optional[EventType[()] | EventType[str]] = None,
        on_scroll: Optional[EventType[()]] = None,
        on_scroll_end: Optional[EventType[()]] = None,
        on_unmount: Optional[EventType[()]] = None,
        on_year_control_mouse_enter: Optional[EventType[()] | EventType[str]] = None,
        on_year_select: Optional[EventType[()] | EventType[str]] = None,
        **props,
    ) -> "MonthPicker":
        """Create the Reflex Enterprise component."""
        ...

class MonthPickerInput(BareCalendarPicker):
    @classmethod
    def create(
        cls,
        *children,
        date: Var[str] | str | None = None,
        default_date: Var[str] | str | None = None,
        placeholder: Var[str] | str | None = None,
        aria_labels: Var[dict[str, str]] | dict[str, str] | None = None,
        columns_to_scroll: Var[int] | int | None = None,
        decade_label_format: Var[str] | str | None = None,
        default_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        first_day_of_week: Var[int] | int | None = None,
        get_day_aria_label: Callable | Var[Callable] | None = None,
        get_day_props: Callable | Var[Callable] | None = None,
        get_month_control_props: Callable | Var[Callable] | None = None,
        get_year_control_props: Callable | Var[Callable] | None = None,
        hide_outside_dates: Var[bool] | bool | None = None,
        hide_weekdays: Var[bool] | bool | None = None,
        highlight_today: Var[bool] | bool | None = None,
        level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        locale: Var[str] | str | None = None,
        max_date: Var[str] | str | None = None,
        max_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        min_date: Var[str] | str | None = None,
        min_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        month_label_format: Var[str] | str | None = None,
        month_format: Var[str] | str | None = None,
        next_icon: Component | Var[Component] | None = None,
        next_label: Var[str] | str | None = None,
        number_of_columns: Var[int] | int | None = None,
        presets: Var[list[PresetEntry]] | list[PresetEntry] | None = None,
        previous_icon: Component | Var[Component] | None = None,
        previous_label: Var[str] | str | None = None,
        render_day: Callable | Var[Callable] | None = None,
        size: Literal["lg", "md", "sm", "xl", "xs"]
        | Var[Literal["lg", "md", "sm", "xl", "xs"]]
        | None = None,
        weekday_format: Var[str] | str | None = None,
        weekend_days: Var[list[int]] | list[int] | None = None,
        with_cell_spacing: Var[bool] | bool | None = None,
        with_week_numbers: Var[bool] | bool | None = None,
        year_label_format: Var[str] | str | None = None,
        year_list_format: Var[str] | str | None = None,
        label: Component | Var[Component | str] | str | None = None,
        label_props: Var[dict] | dict | None = None,
        error: Component | Var[Component | bool | str] | bool | str | None = None,
        error_props: Var[dict] | dict | None = None,
        description: Component | Var[Component | str] | str | None = None,
        description_props: Var[dict] | dict | None = None,
        style: Sequence[Mapping[str, Any]]
        | Mapping[str, Any]
        | Var[Mapping[str, Any]]
        | Breakpoints
        | None = None,
        key: Any | None = None,
        id: Any | None = None,
        ref: Var | None = None,
        class_name: Any | None = None,
        custom_attrs: dict[str, Var | Any] | None = None,
        left_section: Component | Var[Component | str] | str | None = None,
        left_section_props: Var[dict] | dict | None = None,
        left_section_width: Var[float | str] | float | str | None = None,
        left_section_pointer_events: Var[str] | str | None = None,
        right_section: Component | Var[Component | str] | str | None = None,
        right_section_props: Var[dict] | dict | None = None,
        right_section_width: Var[float | str] | float | str | None = None,
        right_section_pointer_events: Var[str] | str | None = None,
        on_blur: Optional[EventType[()]] = None,
        on_change: Optional[EventType[()] | EventType[str]] = None,
        on_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_context_menu: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_date_change: Optional[EventType[()] | EventType[str]] = None,
        on_double_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_focus: Optional[EventType[()]] = None,
        on_level_change: Optional[EventType[()] | EventType[str]] = None,
        on_month_select: Optional[EventType[()] | EventType[str]] = None,
        on_mount: Optional[EventType[()]] = None,
        on_mouse_down: Optional[EventType[()]] = None,
        on_mouse_enter: Optional[EventType[()]] = None,
        on_mouse_leave: Optional[EventType[()]] = None,
        on_mouse_move: Optional[EventType[()]] = None,
        on_mouse_out: Optional[EventType[()]] = None,
        on_mouse_over: Optional[EventType[()]] = None,
        on_mouse_up: Optional[EventType[()]] = None,
        on_next_decade: Optional[EventType[()] | EventType[str]] = None,
        on_next_month: Optional[EventType[()] | EventType[str]] = None,
        on_next_year: Optional[EventType[()] | EventType[str]] = None,
        on_previous_decade: Optional[EventType[()] | EventType[str]] = None,
        on_previous_month: Optional[EventType[()] | EventType[str]] = None,
        on_previous_year: Optional[EventType[()] | EventType[str]] = None,
        on_scroll: Optional[EventType[()]] = None,
        on_scroll_end: Optional[EventType[()]] = None,
        on_unmount: Optional[EventType[()]] = None,
        on_year_control_mouse_enter: Optional[EventType[()] | EventType[str]] = None,
        on_year_select: Optional[EventType[()] | EventType[str]] = None,
        **props,
    ) -> "MonthPickerInput":
        """Create the Reflex Enterprise component."""
        ...

class YearPicker(BareCalendarPicker):
    @classmethod
    def create(
        cls,
        *children,
        date: Var[str] | str | None = None,
        default_date: Var[str] | str | None = None,
        placeholder: Var[str] | str | None = None,
        aria_labels: Var[dict[str, str]] | dict[str, str] | None = None,
        columns_to_scroll: Var[int] | int | None = None,
        decade_label_format: Var[str] | str | None = None,
        default_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        first_day_of_week: Var[int] | int | None = None,
        get_day_aria_label: Callable | Var[Callable] | None = None,
        get_day_props: Callable | Var[Callable] | None = None,
        get_month_control_props: Callable | Var[Callable] | None = None,
        get_year_control_props: Callable | Var[Callable] | None = None,
        hide_outside_dates: Var[bool] | bool | None = None,
        hide_weekdays: Var[bool] | bool | None = None,
        highlight_today: Var[bool] | bool | None = None,
        level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        locale: Var[str] | str | None = None,
        max_date: Var[str] | str | None = None,
        max_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        min_date: Var[str] | str | None = None,
        min_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        month_label_format: Var[str] | str | None = None,
        month_format: Var[str] | str | None = None,
        next_icon: Component | Var[Component] | None = None,
        next_label: Var[str] | str | None = None,
        number_of_columns: Var[int] | int | None = None,
        presets: Var[list[PresetEntry]] | list[PresetEntry] | None = None,
        previous_icon: Component | Var[Component] | None = None,
        previous_label: Var[str] | str | None = None,
        render_day: Callable | Var[Callable] | None = None,
        size: Literal["lg", "md", "sm", "xl", "xs"]
        | Var[Literal["lg", "md", "sm", "xl", "xs"]]
        | None = None,
        weekday_format: Var[str] | str | None = None,
        weekend_days: Var[list[int]] | list[int] | None = None,
        with_cell_spacing: Var[bool] | bool | None = None,
        with_week_numbers: Var[bool] | bool | None = None,
        year_label_format: Var[str] | str | None = None,
        year_list_format: Var[str] | str | None = None,
        label: Component | Var[Component | str] | str | None = None,
        label_props: Var[dict] | dict | None = None,
        error: Component | Var[Component | bool | str] | bool | str | None = None,
        error_props: Var[dict] | dict | None = None,
        description: Component | Var[Component | str] | str | None = None,
        description_props: Var[dict] | dict | None = None,
        style: Sequence[Mapping[str, Any]]
        | Mapping[str, Any]
        | Var[Mapping[str, Any]]
        | Breakpoints
        | None = None,
        key: Any | None = None,
        id: Any | None = None,
        ref: Var | None = None,
        class_name: Any | None = None,
        custom_attrs: dict[str, Var | Any] | None = None,
        left_section: Component | Var[Component | str] | str | None = None,
        left_section_props: Var[dict] | dict | None = None,
        left_section_width: Var[float | str] | float | str | None = None,
        left_section_pointer_events: Var[str] | str | None = None,
        right_section: Component | Var[Component | str] | str | None = None,
        right_section_props: Var[dict] | dict | None = None,
        right_section_width: Var[float | str] | float | str | None = None,
        right_section_pointer_events: Var[str] | str | None = None,
        on_blur: Optional[EventType[()]] = None,
        on_change: Optional[EventType[()] | EventType[str]] = None,
        on_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_context_menu: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_date_change: Optional[EventType[()] | EventType[str]] = None,
        on_double_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_focus: Optional[EventType[()]] = None,
        on_level_change: Optional[EventType[()] | EventType[str]] = None,
        on_month_select: Optional[EventType[()] | EventType[str]] = None,
        on_mount: Optional[EventType[()]] = None,
        on_mouse_down: Optional[EventType[()]] = None,
        on_mouse_enter: Optional[EventType[()]] = None,
        on_mouse_leave: Optional[EventType[()]] = None,
        on_mouse_move: Optional[EventType[()]] = None,
        on_mouse_out: Optional[EventType[()]] = None,
        on_mouse_over: Optional[EventType[()]] = None,
        on_mouse_up: Optional[EventType[()]] = None,
        on_next_decade: Optional[EventType[()] | EventType[str]] = None,
        on_next_month: Optional[EventType[()] | EventType[str]] = None,
        on_next_year: Optional[EventType[()] | EventType[str]] = None,
        on_previous_decade: Optional[EventType[()] | EventType[str]] = None,
        on_previous_month: Optional[EventType[()] | EventType[str]] = None,
        on_previous_year: Optional[EventType[()] | EventType[str]] = None,
        on_scroll: Optional[EventType[()]] = None,
        on_scroll_end: Optional[EventType[()]] = None,
        on_unmount: Optional[EventType[()]] = None,
        on_year_control_mouse_enter: Optional[EventType[()] | EventType[str]] = None,
        on_year_select: Optional[EventType[()] | EventType[str]] = None,
        **props,
    ) -> "YearPicker":
        """Create the Reflex Enterprise component."""
        ...

class YearPickerInput(BareCalendarPicker):
    @classmethod
    def create(
        cls,
        *children,
        date: Var[str] | str | None = None,
        default_date: Var[str] | str | None = None,
        placeholder: Var[str] | str | None = None,
        aria_labels: Var[dict[str, str]] | dict[str, str] | None = None,
        columns_to_scroll: Var[int] | int | None = None,
        decade_label_format: Var[str] | str | None = None,
        default_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        first_day_of_week: Var[int] | int | None = None,
        get_day_aria_label: Callable | Var[Callable] | None = None,
        get_day_props: Callable | Var[Callable] | None = None,
        get_month_control_props: Callable | Var[Callable] | None = None,
        get_year_control_props: Callable | Var[Callable] | None = None,
        hide_outside_dates: Var[bool] | bool | None = None,
        hide_weekdays: Var[bool] | bool | None = None,
        highlight_today: Var[bool] | bool | None = None,
        level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        locale: Var[str] | str | None = None,
        max_date: Var[str] | str | None = None,
        max_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        min_date: Var[str] | str | None = None,
        min_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        month_label_format: Var[str] | str | None = None,
        month_format: Var[str] | str | None = None,
        next_icon: Component | Var[Component] | None = None,
        next_label: Var[str] | str | None = None,
        number_of_columns: Var[int] | int | None = None,
        presets: Var[list[PresetEntry]] | list[PresetEntry] | None = None,
        previous_icon: Component | Var[Component] | None = None,
        previous_label: Var[str] | str | None = None,
        render_day: Callable | Var[Callable] | None = None,
        size: Literal["lg", "md", "sm", "xl", "xs"]
        | Var[Literal["lg", "md", "sm", "xl", "xs"]]
        | None = None,
        weekday_format: Var[str] | str | None = None,
        weekend_days: Var[list[int]] | list[int] | None = None,
        with_cell_spacing: Var[bool] | bool | None = None,
        with_week_numbers: Var[bool] | bool | None = None,
        year_label_format: Var[str] | str | None = None,
        year_list_format: Var[str] | str | None = None,
        label: Component | Var[Component | str] | str | None = None,
        label_props: Var[dict] | dict | None = None,
        error: Component | Var[Component | bool | str] | bool | str | None = None,
        error_props: Var[dict] | dict | None = None,
        description: Component | Var[Component | str] | str | None = None,
        description_props: Var[dict] | dict | None = None,
        style: Sequence[Mapping[str, Any]]
        | Mapping[str, Any]
        | Var[Mapping[str, Any]]
        | Breakpoints
        | None = None,
        key: Any | None = None,
        id: Any | None = None,
        ref: Var | None = None,
        class_name: Any | None = None,
        custom_attrs: dict[str, Var | Any] | None = None,
        left_section: Component | Var[Component | str] | str | None = None,
        left_section_props: Var[dict] | dict | None = None,
        left_section_width: Var[float | str] | float | str | None = None,
        left_section_pointer_events: Var[str] | str | None = None,
        right_section: Component | Var[Component | str] | str | None = None,
        right_section_props: Var[dict] | dict | None = None,
        right_section_width: Var[float | str] | float | str | None = None,
        right_section_pointer_events: Var[str] | str | None = None,
        on_blur: Optional[EventType[()]] = None,
        on_change: Optional[EventType[()] | EventType[str]] = None,
        on_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_context_menu: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_date_change: Optional[EventType[()] | EventType[str]] = None,
        on_double_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_focus: Optional[EventType[()]] = None,
        on_level_change: Optional[EventType[()] | EventType[str]] = None,
        on_month_select: Optional[EventType[()] | EventType[str]] = None,
        on_mount: Optional[EventType[()]] = None,
        on_mouse_down: Optional[EventType[()]] = None,
        on_mouse_enter: Optional[EventType[()]] = None,
        on_mouse_leave: Optional[EventType[()]] = None,
        on_mouse_move: Optional[EventType[()]] = None,
        on_mouse_out: Optional[EventType[()]] = None,
        on_mouse_over: Optional[EventType[()]] = None,
        on_mouse_up: Optional[EventType[()]] = None,
        on_next_decade: Optional[EventType[()] | EventType[str]] = None,
        on_next_month: Optional[EventType[()] | EventType[str]] = None,
        on_next_year: Optional[EventType[()] | EventType[str]] = None,
        on_previous_decade: Optional[EventType[()] | EventType[str]] = None,
        on_previous_month: Optional[EventType[()] | EventType[str]] = None,
        on_previous_year: Optional[EventType[()] | EventType[str]] = None,
        on_scroll: Optional[EventType[()]] = None,
        on_scroll_end: Optional[EventType[()]] = None,
        on_unmount: Optional[EventType[()]] = None,
        on_year_control_mouse_enter: Optional[EventType[()] | EventType[str]] = None,
        on_year_select: Optional[EventType[()] | EventType[str]] = None,
        **props,
    ) -> "YearPickerInput":
        """Create the Reflex Enterprise component."""
        ...

class TimeInput(BareCalendarPicker):
    @classmethod
    def create(
        cls,
        *children,
        placeholder: Var[str] | str | None = None,
        aria_labels: Var[dict[str, str]] | dict[str, str] | None = None,
        columns_to_scroll: Var[int] | int | None = None,
        date: Var[str] | str | None = None,
        decade_label_format: Var[str] | str | None = None,
        default_date: Var[str] | str | None = None,
        default_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        first_day_of_week: Var[int] | int | None = None,
        get_day_aria_label: Callable | Var[Callable] | None = None,
        get_day_props: Callable | Var[Callable] | None = None,
        get_month_control_props: Callable | Var[Callable] | None = None,
        get_year_control_props: Callable | Var[Callable] | None = None,
        hide_outside_dates: Var[bool] | bool | None = None,
        hide_weekdays: Var[bool] | bool | None = None,
        highlight_today: Var[bool] | bool | None = None,
        level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        locale: Var[str] | str | None = None,
        max_date: Var[str] | str | None = None,
        max_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        min_date: Var[str] | str | None = None,
        min_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        month_label_format: Var[str] | str | None = None,
        month_format: Var[str] | str | None = None,
        next_icon: Component | Var[Component] | None = None,
        next_label: Var[str] | str | None = None,
        number_of_columns: Var[int] | int | None = None,
        presets: Var[list[PresetEntry]] | list[PresetEntry] | None = None,
        previous_icon: Component | Var[Component] | None = None,
        previous_label: Var[str] | str | None = None,
        render_day: Callable | Var[Callable] | None = None,
        size: Literal["lg", "md", "sm", "xl", "xs"]
        | Var[Literal["lg", "md", "sm", "xl", "xs"]]
        | None = None,
        weekday_format: Var[str] | str | None = None,
        weekend_days: Var[list[int]] | list[int] | None = None,
        with_cell_spacing: Var[bool] | bool | None = None,
        with_week_numbers: Var[bool] | bool | None = None,
        year_label_format: Var[str] | str | None = None,
        year_list_format: Var[str] | str | None = None,
        label: Component | Var[Component | str] | str | None = None,
        label_props: Var[dict] | dict | None = None,
        error: Component | Var[Component | bool | str] | bool | str | None = None,
        error_props: Var[dict] | dict | None = None,
        description: Component | Var[Component | str] | str | None = None,
        description_props: Var[dict] | dict | None = None,
        style: Sequence[Mapping[str, Any]]
        | Mapping[str, Any]
        | Var[Mapping[str, Any]]
        | Breakpoints
        | None = None,
        key: Any | None = None,
        id: Any | None = None,
        ref: Var | None = None,
        class_name: Any | None = None,
        custom_attrs: dict[str, Var | Any] | None = None,
        left_section: Component | Var[Component | str] | str | None = None,
        left_section_props: Var[dict] | dict | None = None,
        left_section_width: Var[float | str] | float | str | None = None,
        left_section_pointer_events: Var[str] | str | None = None,
        right_section: Component | Var[Component | str] | str | None = None,
        right_section_props: Var[dict] | dict | None = None,
        right_section_width: Var[float | str] | float | str | None = None,
        right_section_pointer_events: Var[str] | str | None = None,
        on_blur: Optional[EventType[()]] = None,
        on_change: Optional[EventType[()] | EventType[str]] = None,
        on_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_context_menu: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_date_change: Optional[EventType[()] | EventType[str]] = None,
        on_double_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_focus: Optional[EventType[()]] = None,
        on_level_change: Optional[EventType[()] | EventType[str]] = None,
        on_month_select: Optional[EventType[()] | EventType[str]] = None,
        on_mount: Optional[EventType[()]] = None,
        on_mouse_down: Optional[EventType[()]] = None,
        on_mouse_enter: Optional[EventType[()]] = None,
        on_mouse_leave: Optional[EventType[()]] = None,
        on_mouse_move: Optional[EventType[()]] = None,
        on_mouse_out: Optional[EventType[()]] = None,
        on_mouse_over: Optional[EventType[()]] = None,
        on_mouse_up: Optional[EventType[()]] = None,
        on_next_decade: Optional[EventType[()] | EventType[str]] = None,
        on_next_month: Optional[EventType[()] | EventType[str]] = None,
        on_next_year: Optional[EventType[()] | EventType[str]] = None,
        on_previous_decade: Optional[EventType[()] | EventType[str]] = None,
        on_previous_month: Optional[EventType[()] | EventType[str]] = None,
        on_previous_year: Optional[EventType[()] | EventType[str]] = None,
        on_scroll: Optional[EventType[()]] = None,
        on_scroll_end: Optional[EventType[()]] = None,
        on_unmount: Optional[EventType[()]] = None,
        on_year_control_mouse_enter: Optional[EventType[()] | EventType[str]] = None,
        on_year_select: Optional[EventType[()] | EventType[str]] = None,
        **props,
    ) -> "TimeInput":
        """Create the Reflex Enterprise component."""
        ...

class TimePicker(BareCalendarPicker):
    @classmethod
    def create(
        cls,
        *children,
        date: Var[str] | str | None = None,
        default_date: Var[str] | str | None = None,
        placeholder: Var[str] | str | None = None,
        aria_labels: Var[dict[str, str]] | dict[str, str] | None = None,
        columns_to_scroll: Var[int] | int | None = None,
        decade_label_format: Var[str] | str | None = None,
        default_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        first_day_of_week: Var[int] | int | None = None,
        get_day_aria_label: Callable | Var[Callable] | None = None,
        get_day_props: Callable | Var[Callable] | None = None,
        get_month_control_props: Callable | Var[Callable] | None = None,
        get_year_control_props: Callable | Var[Callable] | None = None,
        hide_outside_dates: Var[bool] | bool | None = None,
        hide_weekdays: Var[bool] | bool | None = None,
        highlight_today: Var[bool] | bool | None = None,
        level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        locale: Var[str] | str | None = None,
        max_date: Var[str] | str | None = None,
        max_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        min_date: Var[str] | str | None = None,
        min_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        month_label_format: Var[str] | str | None = None,
        month_format: Var[str] | str | None = None,
        next_icon: Component | Var[Component] | None = None,
        next_label: Var[str] | str | None = None,
        number_of_columns: Var[int] | int | None = None,
        presets: Var[list[PresetEntry]] | list[PresetEntry] | None = None,
        previous_icon: Component | Var[Component] | None = None,
        previous_label: Var[str] | str | None = None,
        render_day: Callable | Var[Callable] | None = None,
        size: Literal["lg", "md", "sm", "xl", "xs"]
        | Var[Literal["lg", "md", "sm", "xl", "xs"]]
        | None = None,
        weekday_format: Var[str] | str | None = None,
        weekend_days: Var[list[int]] | list[int] | None = None,
        with_cell_spacing: Var[bool] | bool | None = None,
        with_week_numbers: Var[bool] | bool | None = None,
        year_label_format: Var[str] | str | None = None,
        year_list_format: Var[str] | str | None = None,
        label: Component | Var[Component | str] | str | None = None,
        label_props: Var[dict] | dict | None = None,
        error: Component | Var[Component | bool | str] | bool | str | None = None,
        error_props: Var[dict] | dict | None = None,
        description: Component | Var[Component | str] | str | None = None,
        description_props: Var[dict] | dict | None = None,
        style: Sequence[Mapping[str, Any]]
        | Mapping[str, Any]
        | Var[Mapping[str, Any]]
        | Breakpoints
        | None = None,
        key: Any | None = None,
        id: Any | None = None,
        ref: Var | None = None,
        class_name: Any | None = None,
        custom_attrs: dict[str, Var | Any] | None = None,
        left_section: Component | Var[Component | str] | str | None = None,
        left_section_props: Var[dict] | dict | None = None,
        left_section_width: Var[float | str] | float | str | None = None,
        left_section_pointer_events: Var[str] | str | None = None,
        right_section: Component | Var[Component | str] | str | None = None,
        right_section_props: Var[dict] | dict | None = None,
        right_section_width: Var[float | str] | float | str | None = None,
        right_section_pointer_events: Var[str] | str | None = None,
        on_blur: Optional[EventType[()]] = None,
        on_change: Optional[EventType[()] | EventType[str]] = None,
        on_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_context_menu: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_date_change: Optional[EventType[()] | EventType[str]] = None,
        on_double_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_focus: Optional[EventType[()]] = None,
        on_level_change: Optional[EventType[()] | EventType[str]] = None,
        on_month_select: Optional[EventType[()] | EventType[str]] = None,
        on_mount: Optional[EventType[()]] = None,
        on_mouse_down: Optional[EventType[()]] = None,
        on_mouse_enter: Optional[EventType[()]] = None,
        on_mouse_leave: Optional[EventType[()]] = None,
        on_mouse_move: Optional[EventType[()]] = None,
        on_mouse_out: Optional[EventType[()]] = None,
        on_mouse_over: Optional[EventType[()]] = None,
        on_mouse_up: Optional[EventType[()]] = None,
        on_next_decade: Optional[EventType[()] | EventType[str]] = None,
        on_next_month: Optional[EventType[()] | EventType[str]] = None,
        on_next_year: Optional[EventType[()] | EventType[str]] = None,
        on_previous_decade: Optional[EventType[()] | EventType[str]] = None,
        on_previous_month: Optional[EventType[()] | EventType[str]] = None,
        on_previous_year: Optional[EventType[()] | EventType[str]] = None,
        on_scroll: Optional[EventType[()]] = None,
        on_scroll_end: Optional[EventType[()]] = None,
        on_unmount: Optional[EventType[()]] = None,
        on_year_control_mouse_enter: Optional[EventType[()] | EventType[str]] = None,
        on_year_select: Optional[EventType[()] | EventType[str]] = None,
        **props,
    ) -> "TimePicker":
        """Create the Reflex Enterprise component."""
        ...

class TimeGrid(BareCalendarPicker):
    @classmethod
    def create(
        cls,
        *children,
        data: Var[list[str]] | list[str] | None = None,
        placeholder: Var[str] | str | None = None,
        aria_labels: Var[dict[str, str]] | dict[str, str] | None = None,
        columns_to_scroll: Var[int] | int | None = None,
        date: Var[str] | str | None = None,
        decade_label_format: Var[str] | str | None = None,
        default_date: Var[str] | str | None = None,
        default_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        first_day_of_week: Var[int] | int | None = None,
        get_day_aria_label: Callable | Var[Callable] | None = None,
        get_day_props: Callable | Var[Callable] | None = None,
        get_month_control_props: Callable | Var[Callable] | None = None,
        get_year_control_props: Callable | Var[Callable] | None = None,
        hide_outside_dates: Var[bool] | bool | None = None,
        hide_weekdays: Var[bool] | bool | None = None,
        highlight_today: Var[bool] | bool | None = None,
        level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        locale: Var[str] | str | None = None,
        max_date: Var[str] | str | None = None,
        max_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        min_date: Var[str] | str | None = None,
        min_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        month_label_format: Var[str] | str | None = None,
        month_format: Var[str] | str | None = None,
        next_icon: Component | Var[Component] | None = None,
        next_label: Var[str] | str | None = None,
        number_of_columns: Var[int] | int | None = None,
        presets: Var[list[PresetEntry]] | list[PresetEntry] | None = None,
        previous_icon: Component | Var[Component] | None = None,
        previous_label: Var[str] | str | None = None,
        render_day: Callable | Var[Callable] | None = None,
        size: Literal["lg", "md", "sm", "xl", "xs"]
        | Var[Literal["lg", "md", "sm", "xl", "xs"]]
        | None = None,
        weekday_format: Var[str] | str | None = None,
        weekend_days: Var[list[int]] | list[int] | None = None,
        with_cell_spacing: Var[bool] | bool | None = None,
        with_week_numbers: Var[bool] | bool | None = None,
        year_label_format: Var[str] | str | None = None,
        year_list_format: Var[str] | str | None = None,
        label: Component | Var[Component | str] | str | None = None,
        label_props: Var[dict] | dict | None = None,
        error: Component | Var[Component | bool | str] | bool | str | None = None,
        error_props: Var[dict] | dict | None = None,
        description: Component | Var[Component | str] | str | None = None,
        description_props: Var[dict] | dict | None = None,
        style: Sequence[Mapping[str, Any]]
        | Mapping[str, Any]
        | Var[Mapping[str, Any]]
        | Breakpoints
        | None = None,
        key: Any | None = None,
        id: Any | None = None,
        ref: Var | None = None,
        class_name: Any | None = None,
        custom_attrs: dict[str, Var | Any] | None = None,
        left_section: Component | Var[Component | str] | str | None = None,
        left_section_props: Var[dict] | dict | None = None,
        left_section_width: Var[float | str] | float | str | None = None,
        left_section_pointer_events: Var[str] | str | None = None,
        right_section: Component | Var[Component | str] | str | None = None,
        right_section_props: Var[dict] | dict | None = None,
        right_section_width: Var[float | str] | float | str | None = None,
        right_section_pointer_events: Var[str] | str | None = None,
        on_blur: Optional[EventType[()]] = None,
        on_change: Optional[EventType[()] | EventType[str]] = None,
        on_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_context_menu: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_date_change: Optional[EventType[()] | EventType[str]] = None,
        on_double_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_focus: Optional[EventType[()]] = None,
        on_level_change: Optional[EventType[()] | EventType[str]] = None,
        on_month_select: Optional[EventType[()] | EventType[str]] = None,
        on_mount: Optional[EventType[()]] = None,
        on_mouse_down: Optional[EventType[()]] = None,
        on_mouse_enter: Optional[EventType[()]] = None,
        on_mouse_leave: Optional[EventType[()]] = None,
        on_mouse_move: Optional[EventType[()]] = None,
        on_mouse_out: Optional[EventType[()]] = None,
        on_mouse_over: Optional[EventType[()]] = None,
        on_mouse_up: Optional[EventType[()]] = None,
        on_next_decade: Optional[EventType[()] | EventType[str]] = None,
        on_next_month: Optional[EventType[()] | EventType[str]] = None,
        on_next_year: Optional[EventType[()] | EventType[str]] = None,
        on_previous_decade: Optional[EventType[()] | EventType[str]] = None,
        on_previous_month: Optional[EventType[()] | EventType[str]] = None,
        on_previous_year: Optional[EventType[()] | EventType[str]] = None,
        on_scroll: Optional[EventType[()]] = None,
        on_scroll_end: Optional[EventType[()]] = None,
        on_unmount: Optional[EventType[()]] = None,
        on_year_control_mouse_enter: Optional[EventType[()] | EventType[str]] = None,
        on_year_select: Optional[EventType[()] | EventType[str]] = None,
        **props,
    ) -> "TimeGrid":
        """Create the Reflex Enterprise component."""
        ...

class TimeValue(MantineDates):
    @classmethod
    def create(
        cls,
        *children,
        am_pm_labels: Var[dict[Literal["am", "pm"], str]]
        | dict[Literal["am", "pm"], str]
        | None = None,
        format: Literal["12h", "24h"] | Var[Literal["12h", "24h"]] | None = None,
        value: Var[str] | str | None = None,
        with_seconds: Var[bool] | bool | None = None,
        style: Sequence[Mapping[str, Any]]
        | Mapping[str, Any]
        | Var[Mapping[str, Any]]
        | Breakpoints
        | None = None,
        key: Any | None = None,
        id: Any | None = None,
        ref: Var | None = None,
        class_name: Any | None = None,
        custom_attrs: dict[str, Var | Any] | None = None,
        on_blur: Optional[EventType[()]] = None,
        on_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_context_menu: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_double_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_focus: Optional[EventType[()]] = None,
        on_mount: Optional[EventType[()]] = None,
        on_mouse_down: Optional[EventType[()]] = None,
        on_mouse_enter: Optional[EventType[()]] = None,
        on_mouse_leave: Optional[EventType[()]] = None,
        on_mouse_move: Optional[EventType[()]] = None,
        on_mouse_out: Optional[EventType[()]] = None,
        on_mouse_over: Optional[EventType[()]] = None,
        on_mouse_up: Optional[EventType[()]] = None,
        on_scroll: Optional[EventType[()]] = None,
        on_scroll_end: Optional[EventType[()]] = None,
        on_unmount: Optional[EventType[()]] = None,
        **props,
    ) -> "TimeValue":
        """Create the Reflex Enterprise component."""
        ...

class DatesNamespace(rx.ComponentNamespace):
    calendar = staticmethod(Calendar.create)
    date_time_picker = staticmethod(DateTimePicker.create)
    date_picker = staticmethod(DatePicker.create)
    date_picker_input = staticmethod(DatePickerInput.create)
    date_input = staticmethod(DateInput.create)
    month_picker = staticmethod(MonthPicker.create)
    month_picker_input = staticmethod(MonthPickerInput.create)
    year_picker = staticmethod(YearPicker.create)
    year_picker_input = staticmethod(YearPickerInput.create)
    time_input = staticmethod(TimeInput.create)
    time_picker = staticmethod(TimePicker.create)
    time_grid = staticmethod(TimeGrid.create)
    time_value = staticmethod(TimeValue.create)

dates = DatesNamespace()
