"""Stub file for reflex_enterprise/components/mantine/number_formatter.py"""

# ------------------- DO NOT EDIT ----------------------
# This file was generated by `reflex/utils/pyi_generator.py`!
# ------------------------------------------------------
from typing import Any, Literal, Mapping, Optional, Sequence

from reflex.components.core.breakpoints import Breakpoints
from reflex.event import EventType, PointerEventInfo
from reflex.vars.base import Var

from reflex_enterprise.components.mantine.base import MantineCoreBase

class NumberFormatter(MantineCoreBase):
    @classmethod
    def create(
        cls,
        *children,
        allow_negative: Var[bool] | bool | None = None,
        decimal_scale: Var[int] | int | None = None,
        decimal_separator: Var[str] | str | None = None,
        fixed_decimal_scale: Var[bool] | bool | None = None,
        prefix: Var[str] | str | None = None,
        suffix: Var[str] | str | None = None,
        thousand_separator: Var[bool | str] | bool | str | None = None,
        thousands_group_style: Literal["lakh", "none", "thousand", "wan"]
        | Var[Literal["lakh", "none", "thousand", "wan"]]
        | None = None,
        value: Var[float | int | str] | float | int | str | None = None,
        style: Sequence[Mapping[str, Any]]
        | Mapping[str, Any]
        | Var[Mapping[str, Any]]
        | Breakpoints
        | None = None,
        key: Any | None = None,
        id: Any | None = None,
        ref: Var | None = None,
        class_name: Any | None = None,
        custom_attrs: dict[str, Var | Any] | None = None,
        on_blur: Optional[EventType[()]] = None,
        on_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_context_menu: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_double_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_focus: Optional[EventType[()]] = None,
        on_mount: Optional[EventType[()]] = None,
        on_mouse_down: Optional[EventType[()]] = None,
        on_mouse_enter: Optional[EventType[()]] = None,
        on_mouse_leave: Optional[EventType[()]] = None,
        on_mouse_move: Optional[EventType[()]] = None,
        on_mouse_out: Optional[EventType[()]] = None,
        on_mouse_over: Optional[EventType[()]] = None,
        on_mouse_up: Optional[EventType[()]] = None,
        on_scroll: Optional[EventType[()]] = None,
        on_scroll_end: Optional[EventType[()]] = None,
        on_unmount: Optional[EventType[()]] = None,
        **props,
    ) -> "NumberFormatter":
        """Create the Reflex Enterprise component."""
        ...

number_formatter = NumberFormatter.create
