"""Stub file for reflex_enterprise/components/mantine/semi_circle_progress.py"""

# ------------------- DO NOT EDIT ----------------------
# This file was generated by `reflex/utils/pyi_generator.py`!
# ------------------------------------------------------
from typing import Any, Literal, Mapping, Optional, Sequence

from reflex.components.component import Component
from reflex.components.core.breakpoints import Breakpoints
from reflex.event import EventType, PointerEventInfo
from reflex.vars.base import Var

from reflex_enterprise.components.mantine.base import MantineLabelProps

class SemiCircleProgress(MantineLabelProps):
    @classmethod
    def create(
        cls,
        *children,
        value: Var[int] | int | None = None,
        empty_segment_color: Var[str] | str | None = None,
        filled_segment_color: Var[str] | str | None = None,
        fill_direction: Literal["left-to-right", "right-to-left"]
        | Var[Literal["left-to-right", "right-to-left"]]
        | None = None,
        label_position: Literal["bottom", "center"]
        | Var[Literal["bottom", "center"]]
        | None = None,
        orientation: Literal["down", "up"] | Var[Literal["down", "up"]] | None = None,
        size: Var[float | str] | float | str | None = None,
        thickness: Var[float] | float | None = None,
        transition_duration: Var[int] | int | None = None,
        label: Component | Var[Component | str] | str | None = None,
        label_props: Var[dict] | dict | None = None,
        style: Sequence[Mapping[str, Any]]
        | Mapping[str, Any]
        | Var[Mapping[str, Any]]
        | Breakpoints
        | None = None,
        key: Any | None = None,
        id: Any | None = None,
        ref: Var | None = None,
        class_name: Any | None = None,
        custom_attrs: dict[str, Var | Any] | None = None,
        on_blur: Optional[EventType[()]] = None,
        on_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_context_menu: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_double_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_focus: Optional[EventType[()]] = None,
        on_mount: Optional[EventType[()]] = None,
        on_mouse_down: Optional[EventType[()]] = None,
        on_mouse_enter: Optional[EventType[()]] = None,
        on_mouse_leave: Optional[EventType[()]] = None,
        on_mouse_move: Optional[EventType[()]] = None,
        on_mouse_out: Optional[EventType[()]] = None,
        on_mouse_over: Optional[EventType[()]] = None,
        on_mouse_up: Optional[EventType[()]] = None,
        on_scroll: Optional[EventType[()]] = None,
        on_scroll_end: Optional[EventType[()]] = None,
        on_unmount: Optional[EventType[()]] = None,
        **props,
    ) -> "SemiCircleProgress":
        """Create the Reflex Enterprise component."""
        ...

semi_circle_progress = SemiCircleProgress.create
